==> web2sms_0.1.2-0.tar.gz: web2sms-0.1.2/src/providers/o2_germany/translations/o2_germany_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>o2Germany</name>
    <message>
        <location filename="../o2_germany.cpp" line="438"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="547"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>o2GermanyPrivate</name>
    <message>
        <location filename="../o2_germany.cpp" line="195"/>
        <source>loginForm could not be found!</source>
        <translation>loginForm nicht gefunden!</translation>
    </message>
    <message numerus="yes">
        <location filename="../o2_germany.cpp" line="260"/>
        <source>%n free SMS</source>
        <translation>
            <numerusform>Eine Frei-SMS</numerusform>
            <numerusform>%n Frei-SMS</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="301"/>
        <source>frmSMS could not be found!</source>
        <translation>frmSMS nicht gefunden!</translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="354"/>
        <source>HTTP error happened:
%1</source>
        <translation>HTTP Fehler:
%1</translation>
    </message>
</context>
<context>
    <name>o2GermanyProviderPlugin</name>
    <message>
        <location filename="../o2_germany.cpp" line="565"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
</context>
</TS>

==> web2sms_0.1.2-8.tar.gz: web2sms-0.1.2/src/providers/o2_germany/translations/o2_germany_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>o2Germany</name>
    <message>
        <location filename="../o2_germany.cpp" line="446"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="555"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>o2GermanyPrivate</name>
    <message>
        <location filename="../o2_germany.cpp" line="192"/>
        <source>loginForm could not be found!</source>
        <translation>loginForm nicht gefunden!</translation>
    </message>
    <message numerus="yes">
        <location filename="../o2_germany.cpp" line="257"/>
        <source>%n free SMS</source>
        <translation>
            <numerusform>Eine Frei-SMS</numerusform>
            <numerusform>%n Frei-SMS</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="298"/>
        <source>frmSMS could not be found!</source>
        <translation>frmSMS nicht gefunden!</translation>
    </message>
    <message numerus="yes">
        <location filename="../o2_germany.cpp" line="324"/>
        <source>%n* free SMS</source>
        <translation>
            <numerusform>Eine* Frei-SMS</numerusform>
            <numerusform>%n* Frei-SMS</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../o2_germany.cpp" line="362"/>
        <source>HTTP error happened:
%1</source>
        <translation>HTTP Fehler:
%1</translation>
    </message>
</context>
<context>
    <name>o2GermanyProviderPlugin</name>
    <message>
        <location filename="../o2_germany.cpp" line="573"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
</context>
</TS>
